SCons

Package SCons |
[hide private]
[frames] | no frames]

# Source Code for Package SCons

     1  """SCons
     2
     3  The main package for the SCons software construction utility.
     4
     5  """
     6
     7  #
     8  # Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation
     9  #
    10  # Permission is hereby granted, free of charge, to any person obtaining
    11  # a copy of this software and associated documentation files (the
    12  # "Software"), to deal in the Software without restriction, including
    13  # without limitation the rights to use, copy, modify, merge, publish,
    14  # distribute, sublicense, and/or sell copies of the Software, and to
    15  # permit persons to whom the Software is furnished to do so, subject to
    16  # the following conditions:
    17  #
    18  # The above copyright notice and this permission notice shall be included
    19  # in all copies or substantial portions of the Software.
    20  #
    21  # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
    22  # KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
    23  # WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
    24  # NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
    25  # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
    26  # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
    27  # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
    28  #
    29
    30  __revision__ = "src/engine/SCons/__init__.py 5134 2010/08/16 23:02:40 bdeegan"
    31
    32  __version__ = "2.0.1"
    33
    34  __build__ = "r5134"
    35
    36  __buildsys__ = "cooldog"
    37
    38  __date__ = "2010/08/16 23:02:40"
    39
    40  __developer__ = "bdeegan"
    41
    42  # make sure compatibility is always in place
    43  import SCons.compat
    44
    45  # Local Variables:
    46  # tab-width:4
    47  # indent-tabs-mode:nil
    48  # End:
    49  # vim: set expandtab tabstop=4 shiftwidth=4:
    50